@@ -313,13 +313,14 @@ icon_cancel_pressed (IconSelectionData *selection_data)
 static void
 list_icon_selected_callback (GnomeIconList *gil, int num, GdkEvent *event, IconSelectionData *selection_data)
 {
-	const char *icon;
+	char *icon;
 	GtkWidget *entry;
 	
 	icon = gnome_icon_selection_get_icon (GNOME_ICON_SELECTION (selection_data->icon_selection), TRUE);
 	if (icon != NULL) {
 		entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (selection_data->file_entry));
 		gtk_entry_set_text (GTK_ENTRY (entry), icon);
+		g_free (icon);
 	}
 
 	/* handle double-clicks as if the user pressed OK */
